@@ -625,6 +625,9 @@ class Path(object):
                 path_t = _t_child(path_t, 'P', part)
         self.path_t = path_t
 
+    _CACHE = {}
+    _MAX_CACHE = 10000
+
     @classmethod
     def from_text(cls, text):
         """Make a Path from .-delimited text:
@@ -633,7 +636,11 @@ class Path(object):
         Path('a', 'b', 'c')
 
         """
-        return cls(*text.split('.'))
+        if text not in cls._CACHE:
+            if len(cls._CACHE) > cls._MAX_CACHE:
+                return cls(*text.split('.'))
+            cls._CACHE[text] = cls(*text.split('.'))
+        return cls._CACHE[text]
 
     def glomit(self, target, scope):
         # The entrypoint for the Path extension
@@ -987,9 +994,13 @@ class Inspect(object):
             scope[glom] = scope[Inspect]
         if self.echo:
             print('---')
+            # TODO: switch from scope[Path] to the Target-Spec format trace above
+            # ... but maybe be smart about only printing deltas instead of the whole
+            # thing
             print('path:  ', scope[Path] + [spec])
             print('target:', target)
         if self.breakpoint:
+            # TODO: real debugger here?
             self.breakpoint()
         try:
             ret = scope[Inspect](target, spec, scope)
@@ -1420,6 +1431,44 @@ class TType(object):
             # TODO: typecheck kwarg vals?
         return _t_child(self, '(', (args, kwargs))
 
+    def __add__(self, arg):
+        return _t_child(self, '+', arg)
+
+    def __sub__(self, arg):
+        return _t_child(self, '-', arg)
+
+    def __mul__(self, arg):
+        return _t_child(self, '*', arg)
+
+    def __floordiv__(self, arg):
+        return _t_child(self, '#', arg)
+
+    def __truediv__(self, arg):
+        return _t_child(self, '/', arg)
+
+    __div__ = __truediv__
+
+    def __mod__(self, arg):
+        return _t_child(self, '%', arg)
+
+    def __pow__(self, arg):
+        return _t_child(self, ':', arg)
+
+    def __and__(self, arg):
+        return _t_child(self, '&', arg)
+
+    def __or__(self, arg):
+        return _t_child(self, '|', arg)
+
+    def __xor__(self, arg):
+        return _t_child(self, '^', arg)
+
+    def __invert__(self):
+        return _t_child(self, '~', None)
+
+    def __neg__(self):
+        return _t_child(self, '_', None)
+
     def __(self, name):
         return _t_child(self, '.', '__' + name)
 
@@ -1522,6 +1571,34 @@ def _t_eval(target, _t, scope):
             # if args to the call "reset" their path
             # e.g. "T.a" should mean the same thing
             # in both of these specs: T.a and T.b(T.a)
+        else:  # arithmetic operators
+            try:
+                if op == '+':
+                    cur = cur + arg
+                elif op == '-':
+                    cur = cur - arg
+                elif op == '*':
+                    cur = cur * arg
+                #elif op == '#':
+                #    cur = cur // arg  # TODO: python 2 friendly approach?
+                elif op == '/':
+                    cur = cur / arg
+                elif op == '%':
+                    cur = cur % arg
+                elif op == ':':
+                    cur = cur ** arg
+                elif op == '&':
+                    cur = cur & arg
+                elif op == '|':
+                    cur = cur | arg
+                elif op == '^':
+                    cur = cur ^ arg
+                elif op == '~':
+                    cur = ~cur
+                elif op == '_':
+                    cur = -cur
+            except (TypeError, ZeroDivisionError) as e:
+                pae = PathAccessError(e, Path(_t), i // 2)
         if pae:
             raise pae
         i += 2
@@ -1582,6 +1659,18 @@ def _format_t(path, root=T):
             prepr.append(format_invocation(args=args, kwargs=kwargs, repr=bbrepr))
         elif op == 'P':
             return _format_path(path)
+        elif op in ('_', '~'):  # unary arithmetic operators
+            if any([o in path[:i] for o in '+-/%:&|^~_']):
+                prepr = ['('] + prepr + [')']
+            prepr = ['-' if op == '_' else op] + prepr
+        else:  # binary arithmetic operators
+            formatted_arg = bbrepr(arg)
+            if type(arg) is TType:
+                arg_path = _T_PATHS[arg]
+                if any([o in arg_path for o in '+-/%:&|^~_']):
+                    formatted_arg = '(' + formatted_arg + ')'
+            prepr.append(' ' + ('**' if op == ':' else op) + ' ')
+            prepr.append(formatted_arg)
         i += 2
     return "".join(prepr)
 
@@ -1807,6 +1896,7 @@ class TargetRegistry(object):
     def __init__(self, register_default_types=True):
         self._op_type_map = {}
         self._op_type_tree = {}  # see _register_fuzzy_type for details
+        self._type_cache = {}
 
         self._op_auto_map = OrderedDict()  # op name to function that returns handler function
 
@@ -1825,22 +1915,26 @@ class TargetRegistry(object):
         """
         ret = False
         obj_type = type(obj)
-        type_map = self.get_type_map(op)
-        if type_map:
-            try:
-                ret = type_map[obj_type]
-            except KeyError:
-                type_tree = self._op_type_tree.get(op, {})
-                closest = self._get_closest_type(obj, type_tree=type_tree)
-                if closest is None:
-                    ret = False
-                else:
-                    ret = type_map[closest]
+        cache_key = (obj_type, op)
+        if cache_key not in self._type_cache:
+            type_map = self.get_type_map(op)
+            if type_map:
+                try:
+                    ret = type_map[obj_type]
+                except KeyError:
+                    type_tree = self._op_type_tree.get(op, {})
+                    closest = self._get_closest_type(obj, type_tree=type_tree)
+                    if closest is None:
+                        ret = False
+                    else:
+                        ret = type_map[closest]
 
-        if ret is False and raise_exc:
-            raise UnregisteredTarget(op, obj_type, type_map=type_map, path=path)
+            if ret is False and raise_exc:
+                raise UnregisteredTarget(op, obj_type, type_map=type_map, path=path)
 
-        return ret
+            self._type_cache[cache_key] = ret
+
+        return self._type_cache[cache_key]
 
     def get_type_map(self, op):
         try:
@@ -1928,6 +2022,8 @@ class TargetRegistry(object):
             for op_name in new_op_map:
                 self._register_fuzzy_type(op_name, target_type)
 
+        self._type_cache = {}  # reset type cache
+
         return
 
     def register_op(self, op_name, auto_func=None, exact=False):
@@ -2119,21 +2215,23 @@ def _has_callable_glomit(obj):
 
 def _glom(target, spec, scope):
     parent = scope
+    pmap = parent.maps[0]
     scope = scope.new_child({
         T: target,
         Spec: spec,
         UP: parent,
         CHILD_ERRORS: [],
+        MODE: pmap[MODE],
     })
-    parent[LAST_CHILD_SCOPE] = scope
+    pmap[LAST_CHILD_SCOPE] = scope
 
     try:
-        if isinstance(spec, TType):  # must go first, due to callability
+        if type(spec) is TType:  # must go first, due to callability
             return _t_eval(target, spec, scope)
         elif _has_callable_glomit(spec):
             return spec.glomit(target, scope)
 
-        return scope[MODE](target, spec, scope)
+        return scope.maps[0][MODE](target, spec, scope)
     except Exception as e:
         scope.maps[1][CHILD_ERRORS].append(scope)
         scope.maps[0][CUR_ERROR] = e
@@ -2147,6 +2245,8 @@ def _glom(target, spec, scope):
 
 
 def AUTO(target, spec, scope):
+    if type(spec) is str:  # shortcut to make deep-get use case faster
+        return _t_eval(target, Path.from_text(spec).path_t, scope)
     if isinstance(spec, dict):
         return _handle_dict(target, spec, scope)
     elif isinstance(spec, list):
